from django.db import models
from netfields import InetAddressField, NetManager
from netaddr import IPAddress


def validate_v4(address):
    if address.version != 4:
        raise ValidationError('{} is not an IPv4 address'.format(address))

def validate_v6(address):
    if address.version != 6:
        raise ValidationError('{} is not an IPv6 address'.format(address))


class VPNSubscription(models.Model):
    administrative_subscription = models.OneToOneField('offers.OfferSubscription')
    activated = models.BooleanField(default=False)
    login = models.CharField(max_length=50)
    # TODO: define which hash to use
    password = models.CharField(max_length=256)
    ipv4_endpoint = InetAddressField(validators=[validate_v4], blank=True)
    ipv6_endpoint = InetAddressField(validators=[validate_v6], blank=True)

    objects = NetManager()

    def clean(self):
        subnets = self.administrative_subscription.ip_subnet.all()
        # Check that the endpoints are included in one of the routed subnets
        for endpoint in [self.ipv4_endpoint, self.ipv6_endpoint]:
            if endpoint:
                if not any([endpoint in subnet for subnet in subnets]):
                    raise ValidationError("Endpoint {} is not in an attributed range".format(endpoint))

    def __unicode__(self):
        return self.login
